---
feature_story: FS_43_50_57_71
feature_title: internal `echo_args` func
feature_status: TEST
---

Func `echo` replies back with the same args it was invoked with.

The purpose of this function is mostly testing for:
*   FS_61_67_08_53 non-searchable `arg_value`
*   FS_92_75_93_01 clean command line
